@@ -1,10 +1,9 @@
+import janda
 import asyncio
 import os
 import re
 import time
-
-import janda
-import requests
+from .utils.request import get
 from inputimeout import TimeoutOccurred
 
 from .pdf import process_pdf
@@ -27,13 +26,13 @@ h2r = janda.Hentai2read()
 async def get_h2r(ids=choose().hentai2read):
     for id in ids:
         par = id.split(":")
-        await asyncio.gather(process_h2r(par[0], par[1]))
-        print(f"Complete process {par[0]}, chapter {par[1]}")
+        await asyncio.gather(process_h2r(par[0]))
+        print(f"Complete process {par[0]}")
 
 
-async def process_h2r(id: str, chapter: int):
+async def process_h2r(id: str):
     initial = time.time()
-    data = await h2r.get(id, chapter)
+    data = await h2r.get(id)
     parser = janda.resolve(data)
 
     title = re.sub(r"[^\w\s]", "", parser["data"]["title"])
@@ -63,7 +62,7 @@ async def process_h2r(id: str, chapter: int):
 
         while True:
             try:
-                r = requests.get(img_url)
+                content_bytes = await get(img_url)
                 break
             except Exception as e:
                 log_warn(e, f"Retrying {img_name} in 3 seconds...")
@@ -72,7 +71,7 @@ async def process_h2r(id: str, chapter: int):
 
         with open(neat_dir + "/" + img_name, "wb") as f:
 
-            f.write(r.content)
+            f.write(content_bytes)
 
             if os.path.exists(neat_dir + "/" + img_name):
                 log_file(
@@ -104,5 +103,5 @@ async def process_h2r(id: str, chapter: int):
                     process_pdf(neat_dir, parser["data"]["title"])
                 except TimeoutOccurred:
                     print(
-                        f"Timeout occurred, not rendering pdf {id}, chapter: {chapter}"
+                        f"Timeout occurred, not rendering pdf {id}"
                     )
